@@ -314,6 +314,7 @@ grl_net_wc_init (GrlNetWc *wc)
   wc->priv = grl_net_wc_get_instance_private (wc);
 
   wc->priv->session = soup_session_async_new ();
+  g_object_set (G_OBJECT (wc->priv->session), "ssl-use-system-ca-file", TRUE, NULL);
   wc->priv->pending = g_queue_new ();
 
   set_thread_context (wc);
@@ -767,7 +768,7 @@ get_url (GrlNetWc *self,
   } else {
     priv->last_request += priv->throttling;
 
-    GRL_DEBUG ("delaying web request by %lu seconds",
+    GRL_DEBUG ("delaying web request by %" G_GINT64_FORMAT " seconds",
                priv->last_request - now);
     id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
                                      priv->last_request - now,
@@ -947,7 +948,7 @@ grl_net_wc_request_with_headers_hash_async (GrlNetWc *self,
  * @self: a #GrlNetWc instance
  * @result: The result of the request
  * @content: (out) (array length=length) (element-type guint8) (allow-none)
- * (transfer full): The contents of the resource
+ * (transfer none): The contents of the resource
  * @length: (out) (allow-none): The length of the contents or %NULL if it is not
  * needed
  * @error: return location for a #GError, or %NULL
