@@ -1676,6 +1676,9 @@ grl_media_set_mb_artist_id (GrlMedia *media, const gchar *mb_artist_id)
  * Set the MusicBrainz album identifier of the media
  *
  * Since: 0.3.0
+ *
+ * Deprecated: 0.3.8 in favor of more specific metadata-keys
+ * GRL_METADATA_KEY_MB_RELEASE_ID and GRL_METADATA_KEY_MB_RELEASE_GROUP_ID
  */
 void
 grl_media_set_mb_album_id (GrlMedia *media, const gchar *mb_album_id)
@@ -1685,6 +1688,40 @@ grl_media_set_mb_album_id (GrlMedia *media, const gchar *mb_album_id)
                        mb_album_id);
 }
 
+/**
+ * grl_media_set_mb_release_id:
+ * @media: the media instance
+ * @mb_release_id: Album release identifier in MusicBrainz
+ *
+ * Set the MusicBrainz release identifier of the media
+ *
+ * Since: 0.3.8
+ */
+void
+grl_media_set_mb_release_id (GrlMedia *media, const gchar *mb_release_id)
+{
+  g_return_if_fail (GRL_IS_MEDIA (media));
+  grl_data_set_string (GRL_DATA (media), GRL_METADATA_KEY_MB_RELEASE_ID,
+                       mb_release_id);
+}
+
+/**
+ * grl_media_set_mb_release_group_id:
+ * @media: the media instance
+ * @mb_release_group_id:  Album group release identifier in MusicBrainz
+ *
+ * Set the MusicBrainz Release Group identifier of the media
+ *
+ * Since: 0.3.8
+ */
+void
+grl_media_set_mb_release_group_id (GrlMedia *media, const gchar *mb_release_group_id)
+{
+  g_return_if_fail (GRL_IS_MEDIA (media));
+  grl_data_set_string (GRL_DATA (media), GRL_METADATA_KEY_MB_RELEASE_GROUP_ID,
+                       mb_release_group_id);
+}
+
 /**
  * grl_media_set_lyrics:
  * @media: the media instance
@@ -2513,7 +2550,7 @@ grl_media_get_region (GrlMedia *media)
  *
  * Returns the media's age certificate and publication date for the first region.
  * This should usually be the media's most relevant region.
- * Use grl_media_get_region_data_nth() to get the age certificate and 
+ * Use grl_media_get_region_data_nth() to get the age certificate and
  * publication date for other regions.
  *
  * Returns: (transfer none): the ISO-3166-1 of the region where the media was
@@ -2694,7 +2731,7 @@ grl_media_get_last_position (GrlMedia *media)
  * grl_media_get_last_played:
  * @media: the media object
  *
- * Returns: the media's last played time
+ * Returns: (transfer none): the media's last played time
  *
  * Since: 0.3.0
  */
@@ -2983,6 +3020,9 @@ grl_media_get_bitrate (GrlMedia *media)
  * Returns: the MusicBrainz album identifier
  *
  * Since: 0.3.0
+ *
+ * Deprecated: 0.3.8 in favor of more specific metadata-keys
+ * GRL_METADATA_KEY_MB_RELEASE_ID and GRL_METADATA_KEY_MB_RELEASE_GROUP_ID
  */
 const gchar *
 grl_media_get_mb_album_id (GrlMedia *media)
@@ -3064,6 +3104,36 @@ grl_media_get_mb_track_id (GrlMedia *media)
   return grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_MB_TRACK_ID);
 }
 
+/**
+ * grl_media_get_mb_release_id:
+ * @media: the media instance
+ *
+ * Returns: the MusicBrainz release identifier of the media
+ *
+ * Since: 0.3.8
+ */
+const gchar *
+grl_media_get_mb_release_id (GrlMedia *media)
+{
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+  return grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_MB_RELEASE_ID);
+}
+
+/**
+ * grl_media_get_mb_release_group_id:
+ * @media: the media instance
+ *
+ * Returns: the MusicBrainz release group identifier of the media
+ *
+ * Since: 0.3.8
+ */
+const gchar *
+grl_media_get_mb_release_group_id (GrlMedia *media)
+{
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+  return grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_MB_RELEASE_GROUP_ID);
+}
+
 /**
  * grl_media_get_lyrics:
  * @media: the media instance
